; Terry bogard CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

[Command]
name = "2QCF_a"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "2QCF_bc"
command = ~D, DF, F, D, DF, F, b+c
time = 23

;-| Special Motions |------------------------------------------------------
; FBF
[Command]
name = "FBF_a"
command = ~F, B, F, a
time = 25

;fake power geyser - monkey shot
[Command]
name = "monkshot"
command = ~D, DF, F, D, DF, F, s
time = 25

;-----------------
; QCF
[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargebackfwd_x"
command = ~60$B, F, x
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"       ;Required (do not remove)
command = F, F
time = 10

[Command]
name ="BB"       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "fwd_ac"
command = /F, a+c
time = 1

[Command]
name = "down_bc"
command = /D, b+c
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

[Command]
name = "fwdown_a"
command = /DF,a
time = 1

[Command]
name = "fwdown_c"
command = /DF,c
time = 1

[Command]
name = "fwdup_b"
command = /UF,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1
;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd"  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup"   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+c)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type =  ChangeState
value = 2100
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_c"   ;p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2statetype != A	
trigger1 = p2statetype != C	
trigger1 = p2movetype != H
trigger2 = command = "back_c"  ;p2 stand
trigger2 = p2statetype = S
trigger2 = p2statetype != A
trigger2 = p2statetype != C	
trigger2 = p2movetype != H
trigger2 = stateno != 100    ;Not running


;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"

;---------------------------------------------------------------------------
;Fake burn knuckle
[State -1]
type = ChangeState
value = 2200
trigger1 = command = "fwd_ac"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Fake power geyser
[State -1]
type = ChangeState
value = 2201
trigger1 = command = "down_bc"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Fake power geyser - monkey shot
[State -1]
type = ChangeState
value = 2205
trigger1 = command = "monkshot"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = power >= 1000

;---------------------------------------------------------------------------
;Uppercut 2
[State -1]
type = ChangeState
value = 290
triggerall = command = "ab"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Power geyser
[State -1]
type = ChangeState
value = 3000
trigger1 = command = "2QCF_a"
trigger1 = statetype = S
trigger1 = power >= 1000
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Power Charge
[State -1]
type = ChangeState
value = 1200
triggerall = palno != 7
trigger1 = command = "FBF_a"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Dragon punch A 
[State -1]
type = ChangeState
value = 1350
trigger1 = command = "uppercut_a"
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
;Dashpunch A 
[State -1]
type = ChangeState
value = 999
triggerall = command = "QCB_a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Power wave A 
[State -1]
type = ChangeState
value = 1100
triggerall = command = "QCF_a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;uppercut A 
[State -1]
type = ChangeState
value = 250
triggerall = command = "fwdown_a"
trigger1 = statetype = c
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = "a"         ;Place name of command here
triggerall = command != "holddown"  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
;trigger2 = stateno = 200
;trigger2 = time >= 7

;---------------------------------------------------------------------------
;Triple Power geyser
[State -1]
type = ChangeState
value = 3500
trigger1 = command = "2QCF_bc"
trigger1 = statetype = S
trigger1 = power >= 3000
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Dragon punch B 
[State -1]
type = ChangeState
value = 1500
triggerall = palno != 7
trigger1 = command = "uppercut_b"
trigger1 = ctrl = 1
trigger1 = statetype != A

;---------------------------------------------------------------------------
;Crack Shoot 
[State -1]
type = ChangeState
value = 1010
triggerall = command = "QCB_b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Gliding kick
[State -1]
type = ChangeState
value = 1300
triggerall = palno != 8
triggerall = command = "QCF_b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Small power dunk - Smash
[State -1]
type = ChangeState
value = 320
triggerall = palno != 8
triggerall = command = "fwdup_b"
trigger1 = stateno = 250
trigger1 = movehit = 1

;---------------------------------------------------------------------------
;Forward kick B
[State -1]
type = ChangeState
value = 260
triggerall = command = "fwd_b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;speeded high kick combo
[State -1]
type = ChangeState
value = 350
triggerall = command = "b"
trigger1 = stateno = 200
trigger1 = time >= 6

;---------------------------------------------------------------------------
;speeded high kick combo
[State -1]
type = ChangeState
value = 350
triggerall = command = "b"
trigger1 = stateno = 210
trigger1 = time >= 10

;---------------------------------------------------------------------------
;Near Stand_B
[State -1]
type = ChangeState
value = 280
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = P2dist x  <= 55
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
 ;from a Stand_A (state 200)
;trigger2 = stateno = 200
;trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Dashpunch c 
[State -1]
type = ChangeState
value = 998
triggerall = command = "QCB_c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Power geyser c 
[State -1]
type = ChangeState
value = 1110
triggerall = command = "QCF_c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;dash uppercut combo
[State -1]
type = ChangeState
value = 360
triggerall = palno != 8
triggerall = command = "fwdown_c"
trigger1 = stateno = 350
trigger1 = movehit = 1

;---------------------------------------------------------------------------
;turning punch
[State -1]
type = ChangeState
value = 330
triggerall = palno != 8
triggerall = command = "fwd_c"
trigger1 = stateno = 350
trigger1 = movehit = 1

;---------------------------------------------------------------------------
;Power charge uppercut combo
[State -1]
type = ChangeState
value = 370
triggerall = palno != 8
triggerall = command = "fwd_c"
trigger1 = statetype = S
trigger1 = stateno = 290
trigger1 = time >= 15

;---------------------------------------------------------------------------
;Dashing c kick combo
[State -1]
type = ChangeState
value = 340
triggerall = command = "c"
trigger1 = stateno = 350
trigger1 = time >= 5

;---------------------------------------------------------------------------
;Running C
[State -1]
type = ChangeState
value = 110
triggerall = command = "c"
trigger1 = stateno = 100
trigger1 = time >= 4 

;---------------------------------------------------------------------------
;3 punches punch # 2
[State -1]
type = ChangeState
value = 310
triggerall = command = "c"
trigger1 = stateno = 250
trigger1 = movecontact = 1
trigger1 = statetype = S

;---------------------------------------------------------------------------
;3 punches punch # 3
[State -1]
type = ChangeState
value = 311
triggerall = command = "c"
trigger1 = stateno = 310
trigger1 = movecontact = 1
trigger1 = statetype = S

;---------------------------------------------------------------------------
;3 punches punch # 4 - RBS mode
[State -1]
type = ChangeState
value = 312
triggerall = palno = 8
triggerall = command = "c"
trigger1 = stateno = 311
trigger1 = movecontact = 1
trigger1 = statetype = S

;---------------------------------------------------------------------------
;C punch a combo
[State -1]
type = ChangeState
value = 300
triggerall = palno != 8
triggerall = command = "c"
trigger1 = stateno = 200
trigger1 = time >= 6
trigger1 = statetype = S

;---------------------------------------------------------------------------
;Near Stand_C
[State -1]
type = ChangeState
value = 270
triggerall = command = "c"
trigger1 = P2dist X  <= 70
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 220
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;crouch C punch a combo
[State -1]
type = ChangeState
value = 430
triggerall = palno != 8
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = stateno = 400
trigger1 = time >= 4

;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 420
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
;Jump_B forward
[State -1]
type = ChangeState
value = 630
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_C UP
[State -1]
type = ChangeState
value = 650
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X = 0
trigger1 = Pos Y <= -70

;---------------------------------------------------------------------------
;Jump_C forward
[State -1]
type = ChangeState
value = 640
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = vel X != 0
trigger1 = Pos Y <= -65

;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 620
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Taunt
[State -1]
type = ChangeState
value = 195
trigger1 = command = "start"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch walk
[State -1]
type = ChangeState
value = 23
trigger1 = stateno = 11
trigger1 = command = "holddown"
trigger1 = command = "holdfwd"